gnash-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gnash-commit] gnash ChangeLog server/parser/movie_definition....


From: Zou Lunkai
Subject: [Gnash-commit] gnash ChangeLog server/parser/movie_definition....
Date: Sun, 17 Jun 2007 09:07:29 +0000

CVSROOT:        /sources/gnash
Module name:    gnash
Changes by:     Zou Lunkai <zoulunkai>  07/06/17 09:07:28

Modified files:
        .              : ChangeLog 
        server/parser  : movie_definition.h movie_def_impl.h 
                         sprite_definition.h Timeline.h 
        server/swf     : PlaceObject2Tag.h PlaceObject2Tag.cpp 
        server         : dlist.cpp sprite_instance.h sprite_instance.cpp 
        testsuite/misc-ming.all: displaylist_depths_test11.c 
                                 loop_test2.c loop_test2runner.cpp 
                                 loop_test3.c loop_test5.c loop_test8.c 

Log message:
        enable and improve 3rd attempt timeline design, 20 more successes

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/gnash/ChangeLog?cvsroot=gnash&r1=1.3566&r2=1.3567
http://cvs.savannah.gnu.org/viewcvs/gnash/server/parser/movie_definition.h?cvsroot=gnash&r1=1.24&r2=1.25
http://cvs.savannah.gnu.org/viewcvs/gnash/server/parser/movie_def_impl.h?cvsroot=gnash&r1=1.45&r2=1.46
http://cvs.savannah.gnu.org/viewcvs/gnash/server/parser/sprite_definition.h?cvsroot=gnash&r1=1.21&r2=1.22
http://cvs.savannah.gnu.org/viewcvs/gnash/server/parser/Timeline.h?cvsroot=gnash&r1=1.3&r2=1.4
http://cvs.savannah.gnu.org/viewcvs/gnash/server/swf/PlaceObject2Tag.h?cvsroot=gnash&r1=1.10&r2=1.11
http://cvs.savannah.gnu.org/viewcvs/gnash/server/swf/PlaceObject2Tag.cpp?cvsroot=gnash&r1=1.14&r2=1.15
http://cvs.savannah.gnu.org/viewcvs/gnash/server/dlist.cpp?cvsroot=gnash&r1=1.71&r2=1.72
http://cvs.savannah.gnu.org/viewcvs/gnash/server/sprite_instance.h?cvsroot=gnash&r1=1.120&r2=1.121
http://cvs.savannah.gnu.org/viewcvs/gnash/server/sprite_instance.cpp?cvsroot=gnash&r1=1.288&r2=1.289
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/displaylist_depths_test11.c?cvsroot=gnash&r1=1.2&r2=1.3
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/loop_test2.c?cvsroot=gnash&r1=1.5&r2=1.6
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/loop_test2runner.cpp?cvsroot=gnash&r1=1.2&r2=1.3
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/loop_test3.c?cvsroot=gnash&r1=1.1&r2=1.2
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/loop_test5.c?cvsroot=gnash&r1=1.1&r2=1.2
http://cvs.savannah.gnu.org/viewcvs/gnash/testsuite/misc-ming.all/loop_test8.c?cvsroot=gnash&r1=1.3&r2=1.4

Patches:
Index: ChangeLog
===================================================================
RCS file: /sources/gnash/gnash/ChangeLog,v
retrieving revision 1.3566
retrieving revision 1.3567
diff -u -b -r1.3566 -r1.3567
--- ChangeLog   17 Jun 2007 08:49:28 -0000      1.3566
+++ ChangeLog   17 Jun 2007 09:07:26 -0000      1.3567
@@ -1,4 +1,26 @@
-2007-06-16 Sandro Santilli <address@hidden>
+2007-06-17 Zou Lunkai <address@hidden>
+
+       * server/parser/movie_definition.h, 
+         server/parser/movie_def_impl.h,
+         server/parser/sprite_definition.h,
+         server/parser/Timeline.h,
+         server/swf/PlaceObject2Tag.h,
+         server/swf/PlaceObject2Tag.cpp,
+         server/dlist.cpp, 
+         server/sprite_instance.h, server/sprite_instance.cpp:
+         enable and improve the 3rd attempt of timeline-control design, take 
+         ratio into consideration, which is not only used for morphs but also
+         for general characters in lots of swf files. Got 20 more successes, 
+         still need more tests and cleanups. see wiki.
+       * testsuite/misc-ming.all/displaylist_depths_test11.c,
+         testsuite/misc-ming.all/loop_test2.c, 
+         testsuite/misc-ming.all/loop_test2runner.cpp,
+         testsuite/misc-ming.all/loop_test3.c,
+         testsuite/misc-ming.all/loop_test5.c,
+         testsuite/misc-ming.all/loop_test8.c:
+         xchecks to checks.
+         
+2007-06-17 Sandro Santilli <address@hidden>
 
        * libbase/GC.h: fixed a misleading delete count for
          the debugging mode. You can now see that in the UdoG

Index: server/parser/movie_definition.h
===================================================================
RCS file: /sources/gnash/gnash/server/parser/movie_definition.h,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -b -r1.24 -r1.25
--- server/parser/movie_definition.h    28 May 2007 15:41:09 -0000      1.24
+++ server/parser/movie_definition.h    17 Jun 2007 09:07:27 -0000      1.25
@@ -57,6 +57,7 @@
 
 #include <string>
 #include <memory> // for auto_ptr
+#include <map>
 
 // Forward declarations
 namespace gnash {
@@ -569,7 +570,9 @@
        ///     Depth of an instance placed by PlaceObject* tag.
        ///     Assumed to be in the static zone (an assertion would fail 
otherwise).
        ///
-       virtual void addTimelineDepth(int /*depth*/) {}
+       /// @param ratio
+       /// Ratio of an instance defined by PlaceObject2 tag, ranges from 0 to 
65535
+       virtual void addTimelineDepth(int /*depth*/, int /*ratio*/) {}
 
        /// Remove a depth from the timeline depth set in current frame 
        //
@@ -601,8 +604,7 @@
        /// @param depths
        ///     A vector to copy all frame depths to.
        ///
-       virtual void getTimelineDepths(size_t /*frameno*/,
-                       std::vector<int>& /*depths*/)
+       virtual void getTimelineDepths(size_t /*frameno*/, std::map<int, int>& 
/*depths*/) 
        {}
 
 };

Index: server/parser/movie_def_impl.h
===================================================================
RCS file: /sources/gnash/gnash/server/parser/movie_def_impl.h,v
retrieving revision 1.45
retrieving revision 1.46
diff -u -b -r1.45 -r1.46
--- server/parser/movie_def_impl.h      16 Jun 2007 06:55:57 -0000      1.45
+++ server/parser/movie_def_impl.h      17 Jun 2007 09:07:27 -0000      1.46
@@ -616,9 +616,9 @@
        //
        // TODO: implement in base class ?
        //
-       void addTimelineDepth(int depth)
+       void addTimelineDepth(int depth, int ratio)
        {
-               _timeline.addDepth(depth);
+               _timeline.addDepth(depth, ratio);
        }
 
        // See dox in base class
@@ -634,7 +634,7 @@
        //
        // TODO: implement in base class ?
        //
-       void getTimelineDepths(size_t frameno, std::vector<int>& depths)
+       void getTimelineDepths(size_t frameno, std::map<int, int>& depths)
        {
                _timeline.getFrameDepths(frameno, depths);
        }

Index: server/parser/sprite_definition.h
===================================================================
RCS file: /sources/gnash/gnash/server/parser/sprite_definition.h,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -b -r1.21 -r1.22
--- server/parser/sprite_definition.h   15 Jun 2007 15:00:31 -0000      1.21
+++ server/parser/sprite_definition.h   17 Jun 2007 09:07:27 -0000      1.22
@@ -86,9 +86,9 @@
        //
        // TODO: implement in base class ?
        //
-       void addTimelineDepth(int depth)
+       void addTimelineDepth(int depth, int ratio)
        {
-               _timeline.addDepth(depth);
+               _timeline.addDepth(depth, ratio);
        }
 
        // See dox in base class
@@ -104,7 +104,7 @@
        //
        // TODO: implement in base class ?
        //
-       void getTimelineDepths(size_t frameno, std::vector<int>& depths)
+       void getTimelineDepths(size_t frameno, std::map<int, int>& depths)
        {
                _timeline.getFrameDepths(frameno, depths);
        }

Index: server/swf/PlaceObject2Tag.h
===================================================================
RCS file: /sources/gnash/gnash/server/swf/PlaceObject2Tag.h,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -b -r1.10 -r1.11
--- server/swf/PlaceObject2Tag.h        14 Jun 2007 02:03:19 -0000      1.10
+++ server/swf/PlaceObject2Tag.h        17 Jun 2007 09:07:27 -0000      1.11
@@ -19,7 +19,7 @@
 //
 //
 
-/* $Id: PlaceObject2Tag.h,v 1.10 2007/06/14 02:03:19 zoulunkai Exp $ */
+/* $Id: PlaceObject2Tag.h,v 1.11 2007/06/17 09:07:27 zoulunkai Exp $ */
 
 #ifndef GNASH_SWF_PLACEOBJECT2TAG_H
 #define GNASH_SWF_PLACEOBJECT2TAG_H
@@ -99,6 +99,8 @@
 
        static void loader(stream* in, tag_type tag, movie_definition* m);
 
+    int getRatio() const { return m_ratio;}
+
 private:
 
        int     m_tag_type;

Index: server/swf/PlaceObject2Tag.cpp
===================================================================
RCS file: /sources/gnash/gnash/server/swf/PlaceObject2Tag.cpp,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -b -r1.14 -r1.15
--- server/swf/PlaceObject2Tag.cpp      14 Jun 2007 02:03:19 -0000      1.14
+++ server/swf/PlaceObject2Tag.cpp      17 Jun 2007 09:07:27 -0000      1.15
@@ -17,7 +17,7 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
-/* $Id: PlaceObject2Tag.cpp,v 1.14 2007/06/14 02:03:19 zoulunkai Exp $ */
+/* $Id: PlaceObject2Tag.cpp,v 1.15 2007/06/17 09:07:27 zoulunkai Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -377,9 +377,10 @@
     m->add_execute_tag(ch);
 
     int depth = ch->getDepth();
+       int ratio = ch->getRatio();
     if ( depth < 0 && depth >= character::staticDepthOffset )
     {
-       m->addTimelineDepth(ch->getDepth());
+       m->addTimelineDepth(depth, ratio);
     }
     else
     {

Index: server/dlist.cpp
===================================================================
RCS file: /sources/gnash/gnash/server/dlist.cpp,v
retrieving revision 1.71
retrieving revision 1.72
diff -u -b -r1.71 -r1.72
--- server/dlist.cpp    15 Jun 2007 15:00:28 -0000      1.71
+++ server/dlist.cpp    17 Jun 2007 09:07:28 -0000      1.72
@@ -503,10 +503,11 @@
 
        // 1. Find all "timeline depth" for the target frame, querying the
        //    Timeline object in the sprite/movie definition (see 
implementation details)
-       std::vector<int> save;
+       std::map<int, int>  save;
        movieDef.getTimelineDepths(tgtFrame, save);
 
-#define GNASH_DEBUG_TIMELINE 1
+//#define GNASH_DEBUG_TIMELINE 1
+#undef GNASH_DEBUG_TIMELINE
 #ifdef GNASH_DEBUG_TIMELINE
        cout << "Depths found to save: " << endl;
        std::ostream_iterator<int> ostrIter(cout, "," ) ;
@@ -516,7 +517,7 @@
 #endif
 
 
-       typedef std::vector<int>::iterator SeekIter;
+       typedef std::map<int, int>::iterator SeekIter;
 
        SeekIter startSeek = save.begin();
         SeekIter endSeek = save.end();
@@ -559,9 +560,11 @@
                }
 #endif
 
-               /// Only remove if not in the save vector
-               SeekIter match = std::find(startSeek, endSeek, di_depth);
-               if ( match == save.end() )
+               /// Only remove if not in the save vector, 
+               /// or in the save vector but has a different ratio value
+               SeekIter match = save.find(di_depth);
+               if( match == save.end() || 
+                       ( match != save.end() && match->second != 
di->get_ratio() ))
                {
                        // Not to be saved, killing
                        if ( call_unload ) di->unload();

Index: server/sprite_instance.h
===================================================================
RCS file: /sources/gnash/gnash/server/sprite_instance.h,v
retrieving revision 1.120
retrieving revision 1.121
diff -u -b -r1.120 -r1.121
--- server/sprite_instance.h    15 Jun 2007 20:58:52 -0000      1.120
+++ server/sprite_instance.h    17 Jun 2007 09:07:28 -0000      1.121
@@ -476,6 +476,17 @@
        ///
        void    remove_display_object(int depth, int /* id */)
        {
+       character* existing_char = m_display_list.get_character_at_depth(depth);
+               if(existing_char && existing_char->getTimelineInfo())
+               {
+                       // Don't remove characters placed after target frame
+                       /// TODO: Don't remove character placed after the this 
RemoveObject tag
+                       if(m_current_frame <= 
existing_char->getTimelineInfo()->placedInFrame() )
+                       {
+                               return;
+                       }
+               }
+
            set_invalidated();
            m_display_list.remove_display_object(depth);
        }

Index: server/sprite_instance.cpp
===================================================================
RCS file: /sources/gnash/gnash/server/sprite_instance.cpp,v
retrieving revision 1.288
retrieving revision 1.289
diff -u -b -r1.288 -r1.289
--- server/sprite_instance.cpp  15 Jun 2007 20:58:52 -0000      1.288
+++ server/sprite_instance.cpp  17 Jun 2007 09:07:28 -0000      1.289
@@ -74,7 +74,7 @@
 //#define GNASH_DEBUG_REPLACE 1
 
 // Unfed for original design, 2 for second redesign attempt, 3 for third 
redesign attempt
-#define NEW_TIMELINE_DESIGN 2
+#define NEW_TIMELINE_DESIGN 3
 
 
 

Index: server/parser/Timeline.h
===================================================================
RCS file: /sources/gnash/gnash/server/parser/Timeline.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- server/parser/Timeline.h    21 May 2007 17:02:46 -0000      1.3
+++ server/parser/Timeline.h    17 Jun 2007 09:07:27 -0000      1.4
@@ -25,7 +25,7 @@
 #endif
 
 #include <vector>
-#include <set>
+#include <map>
 #include <boost/thread/mutex.hpp>
 
 namespace gnash
@@ -58,7 +58,7 @@
        /// Construct a Timeline instance 
        Timeline()
        {
-               _frameDepths.push_back(DepthSet());
+               _frameDepths.push_back(DepthMap());
        }
 
        /// Destroy a Timeline instance
@@ -102,6 +102,13 @@
 
        /// Add a timeline depth to the current frame 
        //
+       /// @param depth
+       ///     Depth of an instance placed by PlaceObject* tag.
+       ///     Assumed to be in the static zone (an assertion would fail 
otherwise).
+       ///
+       /// @param ratio
+       /// Ratio of an instance defined by PlaceObject* tag, default to zero.
+       ///
        /// Does NOT lock the mutex as this function is intended to be 
        /// called by a single thread (the loader/parser).
        ///
@@ -109,11 +116,11 @@
        ///     Depth of an instance placed by PlaceObject* tag.
        ///     Assumed to be in the static zone (an assertion would fail 
otherwise).
        ///
-       void addDepth(int depth)
+       void addDepth(int depth, int ratio=0)
        {
                assert(depth < 0 && depth >= -16384); // or should be > -16384 
(not ==?)
 
-               _frameDepths.back().insert(depth);
+               _frameDepths.back().insert(DRPair(depth, ratio));
        }
 
        /// Remove a timeline depth from the current frame 
@@ -159,21 +166,24 @@
        ///     
        ///     
        ///
-       void getFrameDepths(size_t frameno, std::vector<int>& depths)
+       void getFrameDepths(size_t frameno, std::map<int, int>& depths)
        {
                assert(frameno < _frameDepths.size());
 
-               DepthSet& from = _frameDepths[frameno];
-               depths.assign(from.begin(), from.end());
+               DepthMap& from = _frameDepths[frameno];
+               depths.insert(from.begin(), from.end());
        }
 
 private:
 
-       /// A set of depths in the static zone
-       typedef std::set<int> DepthSet;
+       /// A pair of depth value and ratio ralue
+       typedef std::map<int, int>::value_type DRPair;
+
+       /// A set of depth-ratio-pairs in the static zone
+       typedef std::map<int, int> DepthMap;
 
-       /// A vector of depth sets (one for each frame)
-       typedef std::vector<DepthSet> FrameDepths;
+       /// A vector of depth maps (one for each frame)
+       typedef std::vector<DepthMap> FrameDepths;
 
        /// Return the number of frames completely defined
        //
@@ -195,7 +205,7 @@
        }
 
 
        /// A set of depth for each frame
        //
        /// Access to this container is mutex-protected
        /// for thread safety. See _frameDepthsMutex.
@@ -213,12 +223,13 @@
        for (Timeline::FrameDepths::const_iterator it=t._frameDepths.begin(), 
itEnd=t._frameDepths.end(); it!=itEnd; ++it)
        {
                os << "[";
-               for (Timeline::DepthSet::const_iterator di=it->begin(), 
de=it->end(); di!=de; ++di)
+               for (Timeline::DepthMap::const_iterator di=it->begin(), 
de=it->end(); di!=de; ++di)
                {
-                       if ( di != it->begin() ) os << ",";
-                       os << *di;
+                       if ( di != it->begin() ) os << ", ";
+                       os << "<" << di->first << ", " << di->second << ">";
                }
                os << "]";
+               os << "\n";
        }
        return os;
 }
@@ -195,7 +205,7 @@
 
 
-       /// A set of depth for each frame
+       /// A map of depths for each frame
        //
        /// Access to this container is mutex-protected

Index: testsuite/misc-ming.all/displaylist_depths_test11.c
===================================================================
RCS file: 
/sources/gnash/gnash/testsuite/misc-ming.all/displaylist_depths_test11.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- testsuite/misc-ming.all/displaylist_depths_test11.c 22 May 2007 15:53:40 
-0000      1.2
+++ testsuite/misc-ming.all/displaylist_depths_test11.c 17 Jun 2007 09:07:28 
-0000      1.3
@@ -168,14 +168,14 @@
     // supposed to be removed on jump back, being on a depth supposed
     // to contain a timeline instance at that time
     // Gnash fails here by removing the instance placed in a later frame
-    "xcheck_equals(_root.depth3Constructed, 2);"
+    "check_equals(_root.depth3Constructed, 2);"
 
     // Gnash fails here by removing the instance placed in a later frame
-    "xcheck_equals(typeof(static1), 'undefined');"
+    "check_equals(typeof(static1), 'undefined');"
 
     // Gnash fails here by removing the instance placed in a later frame
     // (thus placing a new instance)
-    "xcheck_equals(typeof(static2), 'movieclip');"
+    "check_equals(typeof(static2), 'movieclip');"
 
     "totals();"
     );

Index: testsuite/misc-ming.all/loop_test2.c
===================================================================
RCS file: /sources/gnash/gnash/testsuite/misc-ming.all/loop_test2.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -b -r1.5 -r1.6
--- testsuite/misc-ming.all/loop_test2.c        25 May 2007 15:18:05 -0000      
1.5
+++ testsuite/misc-ming.all/loop_test2.c        17 Jun 2007 09:07:28 -0000      
1.6
@@ -140,18 +140,18 @@
 
       // Depths have not be restored
       // (gnash fails because create new instnaces instead)
-      "xcheck_equals(movieClip1.getDepth(), mc2_depth);" 
-      "xcheck_equals(movieClip2.getDepth(), mc1_depth);"
+      "check_equals(movieClip1.getDepth(), mc2_depth);" 
+      "check_equals(movieClip2.getDepth(), mc1_depth);"
 
       // They are still the same instance
       // (gnash fails because create new instnaces instead)
-      "xcheck_equals(movieClip1.secretCode, 'mc1');" 
-      "xcheck_equals(movieClip2.secretCode, 'mc2');"
+      "check_equals(movieClip1.secretCode, 'mc1');" 
+      "check_equals(movieClip2.secretCode, 'mc2');"
 
       // Chars have not been reconstructed
       // (gnash fails because create new instnaces instead)
-      "xcheck_equals(mc1Constructed, 1);"
-      "xcheck_equals(mc2Constructed, 1);"
+      "check_equals(mc1Constructed, 1);"
+      "check_equals(mc2Constructed, 1);"
 
       "totals();"
 

Index: testsuite/misc-ming.all/loop_test2runner.cpp
===================================================================
RCS file: /sources/gnash/gnash/testsuite/misc-ming.all/loop_test2runner.cpp,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -b -r1.2 -r1.3
--- testsuite/misc-ming.all/loop_test2runner.cpp        28 May 2007 15:41:12 
-0000      1.2
+++ testsuite/misc-ming.all/loop_test2runner.cpp        17 Jun 2007 09:07:28 
-0000      1.3
@@ -132,7 +132,7 @@
        // Check that the black square is still behind the red square
        check_pixel(x_left, y, 2, white, 2); 
        check_pixel(x_red, y, 2, red, 2); 
-       xcheck_pixel(x_int, y, 2, red, 2);  // black is *behind* red square
+       check_pixel(x_int, y, 2, red, 2);  // black is *behind* red square
        check_pixel(x_black, y, 2, black, 2);  
        check_pixel(x_right, y, 2, white, 2);  
 }

Index: testsuite/misc-ming.all/loop_test3.c
===================================================================
RCS file: /sources/gnash/gnash/testsuite/misc-ming.all/loop_test3.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- testsuite/misc-ming.all/loop_test3.c        18 May 2007 21:44:16 -0000      
1.1
+++ testsuite/misc-ming.all/loop_test3.c        17 Jun 2007 09:07:28 -0000      
1.2
@@ -143,19 +143,19 @@
       "gotoAndStop(2);"
 
       // Character placed in frame 3 at depth (-16380) was destroyed (placed 
*after* target frame)
-      "xcheck_equals(typeof(movieClip1), 'undefined');" 
+      "check_equals(typeof(movieClip1), 'undefined');" 
       
       // Depth of character at depth -16380 isn't restored (there's no 
character at that depth)
       // (gnash fails because create new instances instead)
-      "xcheck_equals(movieClip2.getDepth(), -16381);"
+      "check_equals(movieClip2.getDepth(), -16381);"
 
       // movieClip2 is still the same instance
       // (gnash fails because create new instance instead)
-      "xcheck_equals(movieClip2.secretCode, 'mc2');"
+      "check_equals(movieClip2.secretCode, 'mc2');"
 
       // Chars have been constructed only once
       // (gnash fails because create new movieClip1 instance instead)
-      "xcheck_equals(mc1Constructed, 1);"
+      "check_equals(mc1Constructed, 1);"
       "check_equals(mc2Constructed, 1);"
 
       "totals();"

Index: testsuite/misc-ming.all/loop_test5.c
===================================================================
RCS file: /sources/gnash/gnash/testsuite/misc-ming.all/loop_test5.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- testsuite/misc-ming.all/loop_test5.c        21 May 2007 08:30:11 -0000      
1.1
+++ testsuite/misc-ming.all/loop_test5.c        17 Jun 2007 09:07:28 -0000      
1.2
@@ -182,12 +182,12 @@
   SWFMovie_add(mo, (SWFBlock)newSWFAction( "gotoAndStop(3);"));
   
   check_equals(mo, "typeof(movieClip1)", "'movieclip'");
-  xcheck_equals(mo, "typeof(movieClip2)", "'undefined'");
+  check_equals(mo, "typeof(movieClip2)", "'undefined'");
   // the difference of movieClip3 and movieClip4 was caused by the ratio value
   check_equals(mo, "typeof(movieClip3)", "'undefined'");
-  xcheck_equals(mo, "typeof(movieClip4)", "'movieclip'");
+  check_equals(mo, "typeof(movieClip4)", "'movieclip'");
   check_equals(mo, "_root.mc1Constructed", "2");
-  xcheck_equals(mo, "_root.mc2Constructed", "1");
+  check_equals(mo, "_root.mc2Constructed", "1");
   check_equals(mo, "_root.mc3Constructed", "1");
   check_equals(mo, "_root.mc4Constructed", "1");
   

Index: testsuite/misc-ming.all/loop_test8.c
===================================================================
RCS file: /sources/gnash/gnash/testsuite/misc-ming.all/loop_test8.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -b -r1.3 -r1.4
--- testsuite/misc-ming.all/loop_test8.c        13 Jun 2007 13:15:51 -0000      
1.3
+++ testsuite/misc-ming.all/loop_test8.c        17 Jun 2007 09:07:28 -0000      
1.4
@@ -218,12 +218,12 @@
   add_actions(mo, "gotoAndStop(3);");
   
   check_equals(mo, "typeof(mc1)", "'movieclip'");
-  xcheck_equals(mo, "typeof(mc2)", "'undefined'"); 
+  check_equals(mo, "typeof(mc2)", "'undefined'"); 
   check_equals(mo, "typeof(mc3)", "'movieclip'"); 
-  xcheck_equals(mo, "typeof(mc4)", "'movieclip'"); 
+  check_equals(mo, "typeof(mc4)", "'movieclip'"); 
   xcheck_equals(mo, "typeof(mc5)", "'movieclip'"); 
   check_equals(mo, "mc1Constructed", "1");
-  xcheck_equals(mo, "mc2Constructed", "1"); 
+  check_equals(mo, "mc2Constructed", "1"); 
   check_equals(mo, "mc3Constructed", "2"); 
   check_equals(mo, "mc4Constructed", "1");
   check_equals(mo, "mc5Constructed", "1");




reply via email to

[Prev in Thread] Current Thread [Next in Thread]